log using StackedRobustnessChecks.txt, text replace
**********************************************************
*StackedRobustnessChecks.do

*Checks the robstness of results of the incumbent game fielded on Mechanical
*Turk by Huber, Hill, and Lenz in March and April 2011.
*Uses data created by LoadIncumbentGame.do.
**********************************************************

clear
set more off

*Check if model and numboots arguments have been passed to 
*do file. If not, default to reg and 50.
if ("`1'" == "") {
  local model "reg"
  local numboots 50
}
else {
  local model "`1'"
  local numboots `2'
}

*Data created in StackedAnalysis.do.
use "forR-Stacked.dta", clear

*Stuff for writing out p-values.
local modeltext "OLS (bootstrap)"
if ("`model'" == "probit") local modeltext "Probit (bootstrap)"
*Check to see that file connection sigtable is open.
local fileconnection 0
file query
if (`r(N)' > 0) local fileconnection 1

**************************************************
*First, bootstrap results for varying instructions experiment.
**************************************************
`model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_6 Xpayavg13_16_6 interv_6 if interv_4 == 1 | interv_6 == 1
`model' keepallocator payments1_16 payments13_16 Xpayments1_16_6 Xdev13_16_6 interv_6 if interv_4 == 1 | interv_6 == 1
bootstrap b116=_b[Xpayavg1_16_6] b1316=_b[Xpayavg13_16_6], saving("../boots/VaryingInstructionsCutpoint-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_6 Xpayavg13_16_6 interv_6 if interv_4 == 1 | interv_6 == 1
  *Write out p-values for Wald tests on the two coefficients.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on rounds 13-16 greater with instructions in round 12 rather than round 1"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

bootstrap b116=_b[Xpayments1_16_6] b1316=_b[Xdev13_16_6], saving("../boots/VaryingInstructionsContinuous-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payments1_16 payments13_16 Xpayments1_16_6 Xdev13_16_6 interv_6 if interv_4 == 1 | interv_6 == 1
  *Write out p-values for Wald tests on the two coefficients.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on round 13-16 deviations greater with instructions in round 12 rather than round 1"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

*Binned deviation tests.
qui egen devcuts = cut(devpayments13_16) if regexm(intervention,"Instructions|Informed"), group(3) icodes
qui replace devcuts = devcuts - 1
qui gen Xdevcuts=devcuts*interv_6
bootstrap b116=_b[Xpayments1_16_6] b1316=_b[Xdevcuts], saving("../boots/VaryingInstructionsBinned-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payments1_16 devcuts Xpayments1_16_6 Xdevcuts interv_6 if interv_4 == 1 | interv_6 == 1
  *Write out p-values for Wald tests on the two coefficients.
  local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on binned round 13-16 deviations greater with instructions in round 12 rather than round 1"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
  local testtext "Coefficient on overall average greater with instructions in round 1 rather than round 12"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
qui drop devcuts Xdevcuts

**************************************************
*Second, bootstrap results for varying prime experiment.
**************************************************
local hypothesis "Were influenced by rhetoric to give more weight to recent rather than overall incumbent performance"

`model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_2 Xpayavg13_16_2 interv_2 if interv_1 == 1 | interv_2 == 1
`model' keepallocator payments1_16 payments13_16 Xpayments1_16_2 Xdev13_16_2 interv_2 if interv_1 == 1 | interv_2 == 1
bootstrap b116=_b[Xpayavg1_16_2] b1316=_b[Xpayavg13_16_2], saving("../boots/VaryingPrimeCutpoint-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payavggt1200inrounds1_16 payavggt1200inrounds13_16 Xpayavg1_16_2 Xpayavg13_16_2 interv_2 if interv_1 == 1 | interv_2 == 1
  *Write out p-values for Wald tests on the two coefficients.
  local testtext "Coefficient on rounds 13-16 greater with hedonic than informational prime"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Cutpoint,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

bootstrap b116=_b[Xpayments1_16_2] b1316=_b[Xdev13_16_2], saving("../boots/VaryingPrimeContinuous-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payments1_16 payments13_16 Xpayments1_16_2 Xdev13_16_2 interv_2 if interv_1 == 1 | interv_2 == 1
  *Write out p-values for Wald tests on the two coefficients.
  local testtext "Coefficient on round 13-16 deviations greater with hedonic than informational prime"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Continuous,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

*Binned deviation tests.
qui egen devcuts = cut(devpayments13_16) if regexm(intervention,"Prime"), group(3) icodes
qui replace devcuts = devcuts -1
qui gen Xdevcuts=devcuts*interv_2 
bootstrap b116=_b[Xpayments1_16_2] b1316=_b[Xdevcuts], saving("../boots/VaryingPrimeContinuous-`model'.dta",replace) strata(intervention) reps(`numboots'): `model' keepallocator payments1_16 devcuts Xpayments1_16_2 Xdevcuts interv_2 if interv_1 == 1 | interv_2 == 1
  local testtext "Coefficient on binned round 13-16 deviations greater with hedonic than informational prime"
  local b = _b[b1316]
  test b1316
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n
  local testtext "Coefficient on overall average greater with informational than hedonic prime"
  local b = _b[b116]
  test b116
  local onetailed = `r(p)'/2
  local outrow "`hypothesis',`testtext',`modeltext',Binned,`b',`onetailed'"
  if (`fileconnection') file write sigtable "`outrow'" _n

**************************************************
*Third, robustness to round grouping.
**************************************************
local repl "replace"
*Loop over four interventions of interest.
foreach interv in " Instructions  before round 1" "Informed later (after round 12)" "  Hedonic Prime" "  Informational Prime" {
  *Loop over four starting groupings for final rounds group.
  forvalues startround=13/16 {
    di "`startround'"
    qui egen paymentsgroup  = rowmean(pay`startround'-pay16)
    qui gen paygroupavggt1200 = (paymentsgroup > 1200)
    label variable paygroupavggt1200 "Average > 1200 in rounds `startround'-16"
    qui replace paymentsgroup = paymentsgroup/100
    label variable paymentsgroup "Average Payment in Rounds `startround'-16"
    qui gen devpaymentsgroup = (paymentsgroup-payments1_16)
    label variable devpaymentsgroup "Average payment deviations in Rounds `startround'-16"
    
    `model' keepallocator payments1_16 devpaymentsgroup if intervention == "`interv'"
    outreg using "../papertables/TableA06_RobustnessToGroupings-`model'.out", se ctitle("Allocator Retention, `interv'") bracket rdec(3) 3aster `repl'
    local repl "append"
    
    drop paymentsgroup paygroupavggt1200 devpaymentsgroup
  }
  forvalues startround=13/16 {
    di "`startround'"
    qui egen paymentsgroup  = rowmean(pay`startround'-pay16)
    qui gen paygroupavggt1200 = (paymentsgroup > 1200)
    label variable paygroupavggt1200 "Average > 1200 in rounds `startround'-16"
    qui replace paymentsgroup = paymentsgroup/100
    label variable paymentsgroup "Average Payment in Rounds `startround'-16 (in 100s of tokens)"
    qui gen devpaymentsgroup = (paymentsgroup-payments1_16)
    label variable devpaymentsgroup "Average payment deviations in Rounds `startround'-16"    
 
    `model' keepallocator payavggt1200inrounds1_16 paygroupavggt1200 if intervention == "`interv'"
    outreg using "../papertables/TableA06_RobustnessToGroupings-`model'.out", se ctitle("Allocator Retention, `interv'") bracket rdec(3) 3aster `repl'
    local repl "append"
    
    drop paymentsgroup paygroupavggt1200 devpaymentsgroup
  }
}

*Calculate p-values for each grouping.
local modeltext "OLS (grouped)"
if ("`model'" == "probit") local modeltext "Probit (grouped)"
forvalues startround=13/16 {
  di "`startround'"
  qui egen paymentsgroup  = rowmean(pay`startround'-pay16)
  qui gen paygroupavggt1200 = (paymentsgroup > 1200)
  label variable paygroupavggt1200 "Average > 1200 in rounds `startround'-16"
  qui replace paymentsgroup = paymentsgroup/100
  label variable paymentsgroup "Average Payment in Rounds `startround'-16 (in 100s of tokens)"
  qui gen devpaymentsgroup = (paymentsgroup-payments1_16)
  label variable devpaymentsgroup "Average payment deviations in Rounds `startround'-16"
  qui gen Xdev_2 = devpaymentsgroup*interv_2
  qui gen Xdev_6 = devpaymentsgroup*interv_6

  *Instructions round 1 or 12.
  `model' keepallocator payments1_16 devpaymentsgroup Xpayments1_16_6 Xdev_6 interv_6 if interv_4 == 1 | interv_6 == 1
    local b = _b[Xdev_6]
    test Xdev_6
    local onetailed = `r(p)'/2
    local hypothesis "Overweighted recent incumbent performance when made aware of an election closer rather than more distant from that event"
    local testtext "Coefficient on final round deviations greater with instructions in round 12 rather than round 1"
    local outrow "`hypothesis',`testtext',`modeltext',Continuous (`startround'-16),`b',`onetailed'"
    if (`fileconnection') file write sigtable "`outrow'" _n
    local hypothesis "Underweighted overall incumbent performance when made aware of an election closer rather than more distant from that event"
    local testtext "Coefficient on overall average greater with informational than hedonic prime"
    local b = _b[Xpayments1_16_6]
    test Xpayments1_16_6
    local onetailed = `r(p)'/2
    local outrow "`hypothesis',`testtext',`modeltext',Continuous (`startround'-16),`b',`onetailed'"
    if (`fileconnection') file write sigtable "`outrow'" _n
  
  *Hedonic v informational prime.
  local hypothesis "Were influenced by rhetoric to give more weight to recent rather than overall incumbent performance"
  `model' keepallocator payments1_16 devpaymentsgroup Xpayments1_16_2 Xdev_2 interv_2 if interv_1 == 1 | interv_2 == 1
    local testtext "Coefficient on final round deviations greater with hedonic than informational prime"
    local b = _b[Xdev_2]
    test Xdev_2
    local onetailed = `r(p)'/2
    local outrow "`hypothesis',`testtext',`modeltext',Continuous (`startround'-16),`b',`onetailed'"
    if (`fileconnection') file write sigtable "`outrow'" _n
    local testtext "Coefficient on overall average greater with informational than hedonic prime"
    local b = _b[Xpayments1_16_2]
    test Xpayments1_16_2
    local onetailed = `r(p)'/2
    local outrow "`hypothesis',`testtext',`modeltext',Continuous (`startround'-16),`b',`onetailed'"
    if (`fileconnection') file write sigtable "`outrow'" _n
  
  drop paymentsgroup paygroupavggt1200 devpaymentsgroup Xdev_2 Xdev_6
}

capture log close
